.. :changelog:

History
-------

0.0.1 (16-09-2017)
---------------------

* First code creation


1.0.0 (07-07-2021)
------------------

* Dropped support for python2.7, updated the template and setup a pipeline for release.
